Fixtures
========

``afs``
-------

An "asyncio filesystem" object, which is an instance of
:class:`pyfakefs.fake_filesystem.FakeFilesystem`. See pyfakefs_ for
more details.

.. _pyfakefs: http://jmcgeheeiv.github.io/pyfakefs/pyfakefs.html#pyfakefs.fake_filesystem.FakeFilesystem
